@@ -12,5 +12,6 @@ def post(
 ) -> None:
     json = dict(kwargs)
     json['info'] = info
-    result = requests.post(Api.BASE_URL + "/" + endpoint, json=json)
+    api = Api()
+    result = requests.post(api.get_base_url() + "/" + endpoint, json=json)
     return result
