@@ -173,27 +173,6 @@ class KnapsackDataset(object):
             for task in tqdm.asyncio.tqdm.as_completed(tasks):
                 await task
 
-    # async def _transfer_all_files(
-    #     self,
-    #     src: FSStore,
-    #     dst: FSStore,
-    #     blueprint: Blueprint,
-    #     cloud_provider_info: Dict[str, Any],
-    # ):
-    #     async with ClientSession() as session:
-    #         Parallel(n_jobs=20, backend='threading')(delayed(self._transfer_file)(
-    #             src,
-    #             dst,
-    #             Path(file),
-    #             blueprint.get_bucket_url(),
-    #         ) for file in src.iterate_over_files(self.org_name, self.name, blueprint))
-    #         src_blueprints = src.read_blueprints(
-    #             self.org_name, self.name,
-    #         )
-    #         dst.update_blueprints(
-    #             src_blueprints, self.org_name, self.name,
-    #         )
-
     def _transfer_file(
         self,
         src: BaseStore,
@@ -228,10 +207,9 @@ class KnapsackDataset(object):
                 b2_file_path=dst.root / Path(bucket_url) / filename
             )
         else:
-            # data = src.read_bytes_from_file(full_src_file_path)
-            data = b""
+            data = src.read_bytes_from_file(full_src_file_path)
             dst.store_file(
-                src_file=data,
+                src_file=full_src_file_path,
                 bucket_url=bucket_url,
                 filename=filename,
             )
@@ -527,6 +505,11 @@ class KnapsackDataset(object):
         blueprint: Blueprint,
         kd_builder: KDBuilder
     ) -> None:
+        executor = concurrent.futures.ThreadPoolExecutor(
+            max_workers=self.MAX_WORKERS,
+        )
+        loop = asyncio.get_event_loop()
+
         self.current_local_knapsack.prep_for_store(
             self.org_name, self.name, blueprint.get_repro_tag(), None
         )
@@ -536,14 +519,14 @@ class KnapsackDataset(object):
 
         for i, dp_idx in enumerate(dp_idxs.iterate()):
             file = kd_builder[i]
-            # ext = Path(file).suffix
-            tasks.append(
-                self.current_local_knapsack.store_file(
-                    src_file=Path(file),
-                    bucket_url=self.org_name,
-                    filename=Path(f"{dp_idx}"),
-                )
-            )
+
+            tasks.append(loop.run_in_executor(
+                executor,
+                self.current_local_knapsack.store_file,
+                Path(file),
+                self.org_name,
+                Path(f"{dp_idx}"),
+            ))
             dp_idxs.record_original_filename(
                 file.name, idx
             )
